@@ -1,11 +1,11 @@
 #!/usr/bin/python3
 
-# $Id: rst2xetex.py 7038 2011-05-19 09:12:02Z milde $
+# $Id: rst2xetex.py 7847 2015-03-17 17:30:47Z milde $
 # Author: Guenter Milde
 # Copyright: This module has been placed in the public domain.
 
 """
-A minimal front end to the Docutils Publisher, producing XeLaTeX source code.
+A minimal front end to the Docutils Publisher, producing Lua/XeLaTeX code.
 """
 
 try:
@@ -16,8 +16,9 @@ except:
 
 from docutils.core import publish_cmdline
 
-description = ('Generates XeLaTeX documents from standalone reStructuredText '
-               'sources. '
+description = ('Generates LaTeX documents from standalone reStructuredText '
+               'sources for compilation with the Unicode-aware TeX variants '
+               'XeLaTeX or LuaLaTeX. '
                'Reads from <source> (default is stdin) and writes to '
                '<destination> (default is stdout).  See '
                '<http://docutils.sourceforge.net/docs/user/latex.html> for '
