@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # :Author: Günter Milde <milde@users.sourceforge.net>
-# :Revision: $Revision: 7852 $
-# :Date: $Date: 2015-03-21 17:07:49 +0100 (Sa, 21. Mär 2015) $
+# :Revision: $Revision: 8046 $
+# :Date: $Date: 2017-03-11 13:09:36 +0100 (Sa, 11 Mär 2017) $
 # :Copyright: © 2010 Günter Milde.
 # :License: Released under the terms of the `2-Clause BSD license`_, in short:
 # 
@@ -99,6 +99,11 @@ class Babel(latex2e.Babel):
     for key in ('af',           # 'afrikaans',
                 'de-AT',        # 'naustrian',
                 'de-AT-1901',   # 'austrian',
+                # TODO: use variant=... for English variants
+                'en-CA',        # 'canadian',
+                'en-GB',        # 'british',
+                'en-NZ',        # 'newzealand',
+                'en-US',        # 'american',
                 'fr-CA',        # 'canadien',
                 'grc-ibycus',   # 'ibycus', (Greek Ibycus encoding)
                 'sr-Latn',      # 'serbian script=latin'
@@ -110,12 +115,12 @@ class Babel(latex2e.Babel):
         self.reporter = reporter
         self.language = self.language_name(language_code)
         self.otherlanguages = {}
-        self.warn_msg = 'Language "%s" not supported by XeTeX (polyglossia).'
+        self.warn_msg = 'Language "%s" not supported by Polyglossia.'
         self.quote_index = 0
         self.quotes = ('"', '"')
         # language dependent configuration:
         # double quotes are "active" in some languages (e.g. German).
-        self.literal_double_quote = '"' # TODO: use \textquotedbl
+        self.literal_double_quote = '"' # TODO: use \textquotedbl ?
 
     def __call__(self):
         setup = [r'\usepackage{polyglossia}',
@@ -127,6 +132,12 @@ class Babel(latex2e.Babel):
 
 
 class XeLaTeXTranslator(latex2e.LaTeXTranslator):
+    """
+    Generate code for LaTeX using Unicode fonts (XeLaTex or LuaLaTeX).
+
+    See the docstring of docutils.writers._html_base.HTMLTranslator for
+    notes on and examples of safe subclassing.
+    """
 
     def __init__(self, document):
         self.is_xetex = True  # typeset with XeTeX or LuaTeX engine
